@@ -7,6 +7,7 @@ import docutils.utils
 import docutils.frontend
 from docutils import nodes
 from docutils.parsers.rst import Directive
+from docutils.statemachine import ViewList
 from sphinx.directives.code import container_wrapper
 
 from .loader import JsonSchemaLoader
@@ -77,23 +78,23 @@ class JsonSchema(Directive):
         section = nodes.section(ids=[title], names=[title])
         titlenode = nodes.title(title, title)
         section += titlenode
-        desc = nodes.description()
         description = prop.get("description", "")
-        desc_node = parse_rst(description)
-        desc += desc_node
+        desc_view = ViewList(description.split("\n"))
+        desc = nodes.description()
+        self.state.nested_parse(desc_view, self.content_offset, desc)
         section += desc
         is_required = title in self.required_properties
         required = nodes.description()
-        required_label = nodes.strong("Required")
-        required_text = nodes.inline(f"{is_required}")
+        required_label = nodes.strong(text="Required: ")
+        required_text = nodes.inline(text=f"{is_required}")
         required += required_label
         required += required_text
         section += required
         default_value = prop.get("default")
         if default_value:
             default = nodes.description()
-            default_label = nodes.strong("Default")
-            default_text = nodes.inline(f"{default_value}")
+            default_label = nodes.strong(text="Default: ")
+            default_text = nodes.inline(text=f"{default_value}")
             default += default_label
             default += default_text
             section += default
